==> mandelbulber2_2.09.3.orig.tar.gz: mandelbulber2-2.09-3/qt/my_log_widget.h <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2016 Krzysztof Marczak        §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Sebastian Jennen
 *
 * MyLogWidget - promoted QPlainTextEdit widget for log file display
 *
 * This widget monitors the logfile under systemData.logfileName.
 * The lines get parsed with regex and displayed auto-highlighted.
 */

#ifndef MANDELBULBER2_QT_MY_LOG_WIDGET_H_
#define MANDELBULBER2_QT_MY_LOG_WIDGET_H_

#include "../src/system.hpp"
#include <QPlainTextEdit>
#include <QtCore>
#include <QtGui>

class MyLogWidget : public QPlainTextEdit
{
	Q_OBJECT

public:
	explicit MyLogWidget(QWidget *parent = 0);
	~MyLogWidget();

public slots:
	void appendMessage(const QString &text);
	void initFromLogFile();
	QString formatLine(const QString &text);

private:
	bool initializedFromLogFile;
	QRegularExpression *reBasic;
	QRegularExpression *reInnerType;
};

#endif /* MANDELBULBER2_QT_MY_LOG_WIDGET_H_ */

==> mandelbulber2_2.10.orig.tar.gz: mandelbulber2-2.10/qt/my_log_widget.h <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2016-17 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Sebastian Jennen (jenzebas@gmail.com)
 *
 * MyLogWidget - promoted QPlainTextEdit widget for log file display
 *
 * This widget monitors the logfile under systemData.logfileName.
 * The lines get parsed with regex and displayed auto-highlighted.
 */

#ifndef MANDELBULBER2_QT_MY_LOG_WIDGET_H_
#define MANDELBULBER2_QT_MY_LOG_WIDGET_H_

#include <QPlainTextEdit>
#include <QtCore>
#include <QtGui>

class MyLogWidget : public QPlainTextEdit
{
	Q_OBJECT

public:
	explicit MyLogWidget(QWidget *parent = nullptr);
	~MyLogWidget();

public slots:
	void appendMessage(const QString &text);
	void initFromLogFile();
	QString formatLine(const QString &text) const;

private:
	bool initializedFromLogFile;
	QRegularExpression *reBasic;
	QRegularExpression *reInnerType;
};

#endif /* MANDELBULBER2_QT_MY_LOG_WIDGET_H_ */
